@@ -13,6 +13,7 @@ Training:
         -model SCIKIT_MODEL_ENTRYPOINT \\
         -model-features FEATURE_DEFINITION \\
         -model-predict TO_PREDICT \\
+        -model-directory MODEL_DIRECTORY \\
         -model-SCIKIT_PARAMETER_NAME SCIKIT_PARAMETER_VALUE \\
         -sources f=TRAINING_DATA_SOURCE_TYPE \\
         -source-filename TRAINING_DATA_FILE_NAME \\
@@ -26,6 +27,7 @@ Testing and Accuracy:
         -model SCIKIT_MODEL_ENTRYPOINT \\
         -model-features FEATURE_DEFINITION \\
         -model-predict TO_PREDICT \\
+        -model-directory MODEL_DIRECTORY \\
         -sources f=TESTING_DATA_SOURCE_TYPE \\
         -source-filename TESTING_DATA_FILE_NAME \\
         -log debug
@@ -38,6 +40,7 @@ Predicting with trained model:
         -model SCIKIT_MODEL_ENTRYPOINT \\
         -model-features FEATURE_DEFINITION \\
         -model-predict TO_PREDICT \\
+        -model-directory MODEL_DIRECTORY \\
         -sources f=PREDICT_DATA_SOURCE_TYPE \\
         -source-filename PREDICT_DATA_FILE_NAME \\
         -log debug
@@ -52,6 +55,8 @@ Predicting with trained model:
 |                +-------------------------------+----------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
 |                | ElasticNet                    | scikiteln      | `scikiteln <https://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html#sklearn.linear_model.ElasticNet/>`_                                                        |
 |                +-------------------------------+----------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
+|                | RandomForestRegressor         | scikitrfr      | `scikitrfr <https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.RandomForestRegressor.html>`_                                                                                  |
+|                +-------------------------------+----------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
 |                | BayesianRidge                 | scikitbyr      | `scikitbyr <https://scikit-learn.org/stable/modules/generated/sklearn.linear_model.BayesianRidge.html#sklearn.linear_model.BayesianRidge/>`_                                                  |
 |                +-------------------------------+----------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
 |                | Lasso                         | scikitlas      | `scikitlas <https://scikit-learn.org/stable/modules/generated/sklearn.linear_model.Lasso.html#sklearn.linear_model.Lasso/>`_                                                                  |
@@ -218,6 +223,7 @@ Example below uses KMeans Clustering Model on a small randomly generated dataset
     $ dffml train \\
         -model scikitkmeans \\
         -model-features Col1:float:1 Col2:float:1 Col3:float:1 Col4:float:1 \\
+        -model-directory tempdir \\
         -sources f=csv \\
         -source-filename train.csv \\
         -source-readonly \\
@@ -226,6 +232,7 @@ Example below uses KMeans Clustering Model on a small randomly generated dataset
         -model scikitkmeans \\
         -model-features Col1:float:1 Col2:float:1 Col3:float:1 Col4:float:1\\
         -model-tcluster cluster:int:1 \\
+        -model-directory tempdir \\
         -sources f=csv \\
         -source-filename test.csv \\
         -source-readonly \\
@@ -235,6 +242,7 @@ Example below uses KMeans Clustering Model on a small randomly generated dataset
       dffml predict all \\
         -model scikitkmeans \\
         -model-features Col1:float:1 Col2:float:1 Col3:float:1 Col4:float:1 \\
+        -model-directory tempdir \\
         -sources f=csv \\
         -source-filename /dev/stdin \\
         -source-readonly \\
@@ -261,18 +269,19 @@ Example usage of KMeans Clustering Model using python API:
 
 .. code-block:: python
 
-    from dffml import CSVSource, Features, DefFeature
+    from dffml import CSVSource, Features, Feature
     from dffml.noasync import train, accuracy, predict
     from dffml_model_scikit import KMeansModel
 
     model = KMeansModel(
         features=Features(
-            DefFeature("Col1", float, 1),
-            DefFeature("Col2", float, 1),
-            DefFeature("Col3", float, 1),
-            DefFeature("Col4", float, 1),
+            Feature("Col1", float, 1),
+            Feature("Col2", float, 1),
+            Feature("Col3", float, 1),
+            Feature("Col4", float, 1),
         ),
-        tcluster=DefFeature("cluster", int, 1)
+        tcluster=Feature("cluster", int, 1),
+        directory="tempdir",
     )
 
     # Train the model
@@ -311,7 +320,6 @@ Ensure that `predict` and `accuracy` for these algorithms uses training data.
 
 - directory: Path
 
-  - default: ~/.cache/dffml/scikit-{entrypoint}
   - Directory where state should be saved
 
 """
